@@ -337,7 +337,7 @@ static void update_ui_for_album (AlbumDetails *album)
     gtk_widget_set_sensitive (extract_button, FALSE);
     gtk_widget_set_sensitive (extract_menuitem, FALSE);
     gtk_widget_set_sensitive (select_all_menuitem, FALSE);
-    gtk_widget_set_sensitive (deselect_all_menuitem, TRUE);
+    gtk_widget_set_sensitive (deselect_all_menuitem, FALSE);
     gtk_widget_set_sensitive (prev_menuitem, FALSE);
     gtk_widget_set_sensitive (next_menuitem, FALSE);
   } else {
@@ -743,7 +743,7 @@ set_drive_from_device (const char *device)
 
   if (! device)
     return;
-
+  
   drive = nautilus_burn_drive_new_from_path (device);
   g_assert (drive);
 
@@ -1119,6 +1119,7 @@ void on_genre_edit_changed(GtkEditable *widget, gpointer user_data) {
 void on_contents_activate(GtkWidget *button, gpointer user_data) {
   GError *error = NULL;
 
+  /* If/when we drop libgnome, simply spawn the URI ghelp:sound-juicer. */
   gnome_help_display ("sound-juicer", NULL, &error);
   if (error) {
     GtkWidget *dialog;
@@ -1228,20 +1229,21 @@ int main (int argc, char **argv)
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
-  
+
   g_set_application_name (_("Sound Juicer"));
   
   ctx = g_option_context_new ("- Sound Juicer");
   g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
-  g_option_context_add_group (ctx, gtk_get_option_group (FALSE));
   g_option_context_add_group (ctx, gst_init_get_option_group ());
-  if (!g_option_context_parse (ctx, &argc, &argv, &error)) {
-    g_critical ("Failed to initialize: %s\n", error->message);
-    g_error_free (error);
-    return 1;
-  }
+  g_option_context_set_ignore_unknown_options (ctx, TRUE);
+
+  gnome_program_init ("sound-juicer", 	 
+                      VERSION, LIBGNOMEUI_MODULE, 	 
+                      argc, argv, 	 
+                      GNOME_PROGRAM_STANDARD_PROPERTIES,
+                      GNOME_PARAM_GOPTION_CONTEXT, ctx,
+                      NULL);
 
-  gtk_init (&argc, &argv);
   sj_stock_init ();
 
   gtk_window_set_default_icon_from_file (PIXMAPDIR"/sound-juicer.png", NULL);
